==> worker_2.4.0.orig.tar.gz: worker-2.4.0/src/basic_actions.h <==
/* basic_actions.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: basic_actions.h,v 1.6 2001/11/03 17:01:00 ralf Exp $ */

#ifndef BASIC_ACTIONS_H
#define BASIC_ACTIONS_H

#include "wdefines.h"
#include "functionproto.h"

class DNDAction:public FunctionProto
{
public:
  DNDAction(class Worker*);
  virtual ~DNDAction();
  virtual DNDAction *duplicate();
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  void normalmodedndaction();
};

class DoubleClickAction:public FunctionProto
{
public:
  DoubleClickAction(class Worker*);
  virtual ~DoubleClickAction();
  virtual DoubleClickAction *duplicate();
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  void normalmodeddaction();
};

class ShowAction:public FunctionProto
{
public:
  ShowAction(class Worker*);
  virtual ~ShowAction();
  virtual ShowAction *duplicate();
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  void normalmodeshow();
};

class RawShowAction:public FunctionProto
{
public:
  RawShowAction(class Worker*);
  virtual ~RawShowAction();
  virtual RawShowAction *duplicate();
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  void normalmoderawshow();
};

class UserAction:public FunctionProto
{
public:
  UserAction(class Worker*);
  virtual ~UserAction();
  virtual UserAction *duplicate();
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
  virtual bool save(Datei*);
  virtual int load(Datei*);
  virtual int configure();
protected:
  static const char *name;
  int nr;
  void normalmodeuseraction();
};

class ChangeHiddenFlag:public FunctionProto
{
public:
  ChangeHiddenFlag(class Worker*);
  virtual ~ChangeHiddenFlag();
  virtual ChangeHiddenFlag *duplicate();
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual int run(ActionMessage*);
  virtual bool save(Datei*);
  virtual int load(Datei*);
  virtual const char *getDescription();
  virtual int configure();
protected:
  static const char *name;
  int mode;
};

#endif

==> worker_2.8.5.orig.tar.gz: worker-2.8.5/src/basic_actions.h <==
/* basic_actions.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2004 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: basic_actions.h,v 1.9 2004/07/21 21:10:00 ralf Exp $ */

#ifndef BASIC_ACTIONS_H
#define BASIC_ACTIONS_H

#include "wdefines.h"
#include "functionproto.h"

class DNDAction:public FunctionProto
{
public:
  DNDAction();
  virtual ~DNDAction();
  DNDAction( const DNDAction &other );
  DNDAction &operator=( const DNDAction &other );

  virtual DNDAction *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  void normalmodedndaction();
};

class DoubleClickAction:public FunctionProto
{
public:
  DoubleClickAction();
  virtual ~DoubleClickAction();
  DoubleClickAction( const DoubleClickAction &other );
  DoubleClickAction &operator=( const DoubleClickAction &other );

  virtual DoubleClickAction *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  void normalmodeddaction();
};

class ShowAction:public FunctionProto
{
public:
  ShowAction();
  virtual ~ShowAction();
  ShowAction( const ShowAction &other );
  ShowAction &operator=( const ShowAction &other );

  virtual ShowAction *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  void normalmodeshow();
};

class RawShowAction:public FunctionProto
{
public:
  RawShowAction();
  virtual ~RawShowAction();
  RawShowAction( const RawShowAction &other );
  RawShowAction &operator=( const RawShowAction &other );

  virtual RawShowAction *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  void normalmoderawshow();
};

class UserAction:public FunctionProto
{
public:
  UserAction();
  virtual ~UserAction();
  UserAction( const UserAction &other );
  UserAction &operator=( const UserAction &other );

  virtual UserAction *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
  virtual bool save(Datei*);
  virtual int configure();
  int getNr() const;
  void setNr( int n );
protected:
  static const char *name;
  int nr;
  void normalmodeuseraction();
};

class ChangeHiddenFlag:public FunctionProto
{
public:
  ChangeHiddenFlag();
  virtual ~ChangeHiddenFlag();
  ChangeHiddenFlag( const ChangeHiddenFlag &other );
  ChangeHiddenFlag &operator=( const ChangeHiddenFlag &other );

  virtual ChangeHiddenFlag *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  virtual int run(ActionMessage*);
  virtual bool save(Datei*);
  virtual const char *getDescription();
  virtual int configure();
  
  int getMode() const;
  void setMode( int m );
protected:
  static const char *name;
  int mode;
};

#endif
